@@ -1,5 +1,5 @@
 /*
- * $Id: action.h,v 1.20 2001/12/10 22:42:02 tal197 Exp $
+ * $Id: action.h,v 1.20.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * By Thomas Leonard, <tal197@users.sourceforge.net>.
@@ -15,7 +15,7 @@ void action_init(void);
 void action_usage(GList *paths);
 void action_mount(GList	*paths, gboolean open_dir, int quiet);
 void action_delete(GList *paths);
-void action_chmod(GList *paths);
+void action_chmod(GList *paths, gboolean force_recurse, const char *action);
 void action_find(GList *paths);
 void action_move(GList *paths, char *dest, char *leaf, int quiet);
 void action_copy(GList *paths, char *dest, char *leaf, int quiet);
