@@ -1,5 +1,5 @@
 /*
- * $Id: appmenu.c,v 1.22 2002/01/30 13:08:59 tal197 Exp $
+ * $Id: appmenu.c,v 1.22.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -29,7 +29,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#include <parser.h>
+#include <libxml/parser.h>
 
 #include "global.h"
 
