@@ -1,8 +1,8 @@
 /*
- * $Id: fscache.c,v 1.15 2001/12/22 19:32:12 tal197 Exp $
+ * $Id: fscache.c,v 1.19 2002/01/22 16:55:52 tal197 Exp $
  *
  * FSCache - a glib-style object for caching files
- * Copyright (C) 2001, the ROX-Filer team.
+ * Copyright (C) 2002, the ROX-Filer team.
  *
  * A cache object holds stat details about files in a hash table, along
  * with user-specified data. When you want to read in a file try to
@@ -47,6 +47,8 @@ static gint cmp_stats(gconstpointer a, gconstpointer b);
 static void destroy_hash_entry(gpointer key, gpointer data, gpointer user_data);
 static gboolean purge_hash_entry(gpointer key, gpointer data,
 				 gpointer user_data);
+static GFSCacheData *lookup_internal(GFSCache *cache, char *pathname,
+					FSCacheLookup lookup_type);
 
 
 struct PurgeInfo
@@ -146,18 +148,24 @@ gpointer g_fscache_lookup(GFSCache *cache, char *pathname)
 
 /* Force this already-loaded item into the cache. The cache will
  * ref the object if it wants to keep it.
+ * If update_details is FALSE then the timestamp and size aren't recorded.
+ * Generally, you call this function with update_details = TRUE when you
+ * start loading some data and then with update_details = FALSE when you
+ * put in the loaded object.
  */
-void g_fscache_insert(GFSCache *cache, char *pathname, gpointer obj)
+void g_fscache_insert(GFSCache *cache, char *pathname, gpointer obj,
+		      gboolean update_details)
 {
 	GFSCacheData	*data;
 
-	data = g_fscache_lookup_full(cache, pathname,
-					FSCACHE_LOOKUP_INIT, NULL);
+	data = lookup_internal(cache, pathname,
+			update_details ? FSCACHE_LOOKUP_INIT
+				       : FSCACHE_LOOKUP_INSERT);
 
 	if (!data)
 		return;
 
-	if (data->data && cache->unref)
+	if (cache->unref)
 		cache->unref(data->data, cache->user_data);
 	data->data = obj;
 	if (cache->ref)
@@ -166,95 +174,33 @@ void g_fscache_insert(GFSCache *cache, char *pathname, gpointer obj)
 
 /* As g_fscache_lookup, but 'lookup_type' controls what happens if the data
  * is out-of-date.
- * If found is not NULL, use it to indicate whether the cache has an entry
- * for this file (a NULL return could indicate that the data is cached, but
+ * If found is not NULL, use it to indicate whether something is being
+ * returned (a NULL return could indicate that the data is cached, but
  * the data is NULL).
  */
 gpointer g_fscache_lookup_full(GFSCache *cache, char *pathname,
 				FSCacheLookup lookup_type,
 				gboolean *found)
 {
-	struct stat 	info;
-	GFSCacheKey	key;
-	GFSCacheData	*data;
+	GFSCacheData *data;
 
-	g_return_val_if_fail(cache != NULL, NULL);
-	g_return_val_if_fail(pathname != NULL, NULL);
+	g_return_val_if_fail(lookup_type != FSCACHE_LOOKUP_INIT, NULL);
+	
+	data = lookup_internal(cache, pathname, lookup_type);
 
-	if (mc_stat(pathname, &info))
+	if (!data)
 	{
 		if (found)
 			*found = FALSE;
 		return NULL;
 	}
 
-	key.device = info.st_dev;
-	key.inode = info.st_ino;
-
-	data = g_hash_table_lookup(cache->inode_to_stats, &key);
-
 	if (found)
-		*found = (data != NULL);
-
-	if (data)
-	{
-		/* We've cached this file already */
-
-		if (lookup_type == FSCACHE_LOOKUP_PEEK ||
-		    lookup_type == FSCACHE_LOOKUP_INIT)
-			goto out;	/* Never update on peeks */
-		
-		/* Is it up-to-date? */
-
-		if (UPTODATE(data, info))
-			goto out;
-		
-		if (lookup_type == FSCACHE_LOOKUP_ONLY_NEW)
-			return NULL;
-
-		/* Out-of-date */
-		if (cache->update)
-			cache->update(data->data, pathname, cache->user_data);
-		else
-		{
-			if (cache->unref)
-				cache->unref(data->data, cache->user_data);
-			data->data = NULL;
-		}
-	}
-	else
-	{
-		GFSCacheKey *new_key;
-
-		if (lookup_type != FSCACHE_LOOKUP_CREATE &&
-		    lookup_type != FSCACHE_LOOKUP_INIT)
-			return NULL;
-		
-		new_key = g_memdup(&key, sizeof(key));
-
-		data = g_new(GFSCacheData, 1);
-		data->data = NULL;
-
-		g_hash_table_insert(cache->inode_to_stats, new_key, data);
-	}
-
-	data->m_time = info.st_mtime;
-	data->length = info.st_size;
-	data->mode = info.st_mode;
-
-	if (data->data == NULL && lookup_type != FSCACHE_LOOKUP_INIT)
-	{
-		/* Create the object for the file (ie, not an update) */
-		if (cache->load)
-			data->data = cache->load(pathname, cache->user_data);
-	}
-out:
-	data->last_lookup = time(NULL);
-	if (lookup_type == FSCACHE_LOOKUP_INIT)
-		return data;
+		*found = TRUE;
 
 	if (cache->ref)
 		cache->ref(data->data, cache->user_data);
+
 	return data->data;
 }
 
@@ -392,3 +338,89 @@ static gboolean purge_hash_entry(gpointer key, gpointer data,
 
 	return TRUE;
 }
+
+/* As for g_fscache_lookup_full, but return the GFSCacheData rather than
+ * the data it contains. Doesn't increment the refcount.
+ */
+static GFSCacheData *lookup_internal(GFSCache *cache, char *pathname,
+					FSCacheLookup lookup_type)
+{
+	struct stat 	info;
+	GFSCacheKey	key;
+	GFSCacheData	*data;
+
+	g_return_val_if_fail(cache != NULL, NULL);
+	g_return_val_if_fail(pathname != NULL, NULL);
+
+	if (mc_stat(pathname, &info))
+		return NULL;
+
+	key.device = info.st_dev;
+	key.inode = info.st_ino;
+
+	data = g_hash_table_lookup(cache->inode_to_stats, &key);
+
+	if (data)
+	{
+		/* We've cached this file already */
+
+		if (lookup_type == FSCACHE_LOOKUP_PEEK ||
+		    lookup_type == FSCACHE_LOOKUP_INSERT)
+			goto out;	/* Never update on peeks */
+
+		if (lookup_type == FSCACHE_LOOKUP_INIT)
+			goto init;
+
+		/* Is it up-to-date? */
+
+		if (UPTODATE(data, info))
+			goto out;
+		
+		if (lookup_type == FSCACHE_LOOKUP_ONLY_NEW)
+			return NULL;
+
+		/* Out-of-date */
+		if (cache->update)
+			cache->update(data->data, pathname, cache->user_data);
+		else
+		{
+			if (cache->unref)
+				cache->unref(data->data, cache->user_data);
+			data->data = NULL;
+		}
+	}
+	else
+	{
+		GFSCacheKey *new_key;
+
+		if (lookup_type != FSCACHE_LOOKUP_CREATE &&
+		    lookup_type != FSCACHE_LOOKUP_INIT)
+			return NULL;
+		
+		new_key = g_memdup(&key, sizeof(key));
+
+		data = g_new(GFSCacheData, 1);
+		data->data = NULL;
+
+		g_hash_table_insert(cache->inode_to_stats, new_key, data);
+	}
+
+init:
+	data->m_time = info.st_mtime;
+	data->length = info.st_size;
+	data->mode = info.st_mode;
+
+	if (data->data == NULL &&
+		lookup_type != FSCACHE_LOOKUP_INIT &&
+		lookup_type != FSCACHE_LOOKUP_INSERT)
+	{
+		/* Create the object for the file (ie, not an update) */
+		if (cache->load)
+			data->data = cache->load(pathname, cache->user_data);
+	}
+out:
+	data->last_lookup = time(NULL);
+
+	return data;
+}
+
