@@ -1,5 +1,5 @@
 /*
- * $Id: icon.c,v 1.37 2002/01/16 17:58:45 tal197 Exp $
+ * $Id: icon.c,v 1.37.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -27,7 +27,7 @@
 
 #include <gtk/gtkinvisible.h>
 #include <gtk/gtk.h>
-#include <parser.h>
+#include <libxml/parser.h>
 
 #include "global.h"
 
