@@ -1,5 +1,5 @@
 /*
- * $Id: main.h,v 1.16 2001/01/12 17:30:28 tal197 Exp $
+ * $Id: main.h,v 1.17 2001/11/07 12:54:14 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * By Thomas Leonard, <tal197@users.sourceforge.net>.
@@ -9,10 +9,13 @@
 #define _MAIN_H
 
 #include <sys/types.h>
+#include <gtk/gtk.h>
 
 typedef struct _Callback Callback;
 typedef void (*CallbackFn)(gpointer data);
 
+extern GtkTooltips *tooltips;
+
 struct _Callback
 {
 	CallbackFn	callback;
