@@ -1,5 +1,5 @@
 /*
- * $Id: panel.c,v 1.67 2002/01/23 13:13:09 tal197 Exp $
+ * $Id: panel.c,v 1.67.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -28,7 +28,7 @@
 #include <errno.h>
 #include <ctype.h>
 #include <unistd.h>
-#include <parser.h>
+#include <libxml/parser.h>
 
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
