@@ -1,5 +1,5 @@
 /*
- * $Id: pinboard.c,v 1.82 2002/01/23 13:13:09 tal197 Exp $
+ * $Id: pinboard.c,v 1.82.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -27,7 +27,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
-#include <parser.h>
+#include <libxml/parser.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkinvisible.h>
