@@ -1,5 +1,5 @@
 /*
- * $Id: pinboard.h,v 1.14 2001/05/13 14:45:47 tal197 Exp $
+ * $Id: pinboard.h,v 1.15 2001/12/11 22:21:29 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * By Thomas Leonard, <tal197@users.sourceforge.net>.
@@ -10,6 +10,8 @@
 
 extern Pinboard	*current_pinboard;
 
+extern Icon *pinboard_drag_in_progress;
+
 struct _Pinboard {
 	guchar		*name;		/* Leaf name */
 	GList		*icons;
@@ -17,12 +19,13 @@ struct _Pinboard {
 
 void pinboard_init(void);
 void pinboard_activate(guchar *name);
-void pinboard_pin(guchar *path, guchar *name, int x, int y, gboolean corner);
+void pinboard_pin(guchar *path, guchar *name, int x, int y);
 void pinboard_unpin(Icon *icon);
 void pinboard_wink_item(Icon *icon, gboolean timeout);
 void pinboard_clear(void);
 void pinboard_icon_may_update(Icon *icon);
 void pinboard_reshape_icon(Icon *icon);
 void pinboard_save(void);
+void pinboard_move_icons(void);
 
 #endif /* _PINBOARD_H */
