@@ -1,5 +1,5 @@
 /*
- * $Id: support.c,v 1.72 2002/01/30 17:02:12 tal197 Exp $
+ * $Id: support.c,v 1.72.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -36,7 +36,7 @@
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
-#include <parser.h>
+#include <libxml/parser.h>
 
 #include "global.h"
 
