@@ -1,5 +1,5 @@
 /*
- * $Id: usericons.c,v 1.32 2002/02/01 13:56:43 tal197 Exp $
+ * $Id: usericons.c,v 1.32.2.1 2002/07/02 21:38:02 tal197 Exp $
  *
  * ROX-Filer, filer for the ROX desktop project
  * Copyright (C) 2002, the ROX-Filer team.
@@ -29,7 +29,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <fnmatch.h>
-#include <parser.h>
+#include <libxml/parser.h>
 #include <time.h>
 
 #include "global.h"
